\name{krige.bayes}

\alias{krige.bayes}
\alias{krige.bayes.aux1}
\alias{krige.bayes.aux2}
\alias{krige.bayes.aux3}
\alias{krige.bayes.aux10}
\alias{krige.bayes.aux20}
\alias{model.control}
\alias{prior.control}
\alias{output.control}

%- Also NEED an `\alias' for EACH other topic documented here.

\title{Bayesian analysis for Gaussian geostatistical models}

\description{
  The function \code{krige.bayes} performs Bayesian analysis of
  geostatistical data for different levels of uncertainty in the model
  parameters.\cr
  It returns results on the posterior distributions for the model
  parameters and on the predictive distributions for prediction
  locations (if provided).
}

\usage{
krige.bayes(geodata, coords = geodata$coords, data = geodata$data, locations = "no",
        model = model.control(trend.d = "cte", trend.l = "cte",
                              cov.model = "exponential", kappa = 0.5,
                              aniso.pars = NULL, lambda = 1),
        prior = prior.control(beta.prior = c("flat", "normal", "fixed"),
                              beta = NULL, beta.var = NULL,
                              sill.prior = c("reciprocal", "fixed"), sill = NULL,
	                      range.prior = c("uniform", "exponential",
                                    "fixed", "squared.reciprocal", "reciprocal"),
                              exponential.prior.par = 1, range = NULL,
                              range.discrete = NULL,
                              nugget.prior = c("fixed", "uniform"),
                              nugget = 0, nugget.discrete = NULL),
        output = output.control(n.posterior = 1000, n.predictive = NULL,
                                moments = TRUE, simulations.predictive = TRUE,
	                        keep.simulations = TRUE, mean.estimator = TRUE,
                                quantile.estimator =  NULL,
                                probability.estimator = NULL,
                                signal = FALSE, messages.screen = TRUE))
}

%- maybe also `usage' for other objects documented here.

\section{Auxiliary functions}{
  The functions \code{krige.bayes.aux*} and \code{*.control} are auxiliary functions called by  \code{krige.bayes}. 
}

\arguments{
  \item{geodata}{a list contanining elements \code{$coords} and
    \code{$data} as described next. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.}
  \item{coords}{a \emph{nx2} matrix where each row have the 2-D
    coordinates of the \emph{n} data locations.
    By default it takes the
    element \code{$coords} of the argument \code{geodata}, if provided.}
  \item{data}{a vector with \emph{n} data values. By default it takes the
    element \code{$data} of the argument \code{geodata}, if provided.}
  \item{locations}{a \emph{Nx2} matrix or data-frame with the 2-D
    coordinates of the \emph{N} locations to be predicted.
    Defaults to \code{"no"} in which case
    the function returns only results on the posterior distributions of
    the model parameters.}
  \item{model}{Defines model components. See section DETAILS below.}
  \item{prior}{Specification of priors for the model parameters. See section DETAILS below.}
  \item{output}{Defines output options. See section DETAILS below.}
}

\section{Control functions}{
  
  \code{krige.bayes} is a generic function for Bayesian geostatistical 
  analysis where predictions take into account the  parameter
  uncertainty.
  
  It can also be set to run conventional kriging methods which
  uses known parameters or \emph{plug-in} estimates. However, the
  functions \code{krige.conv} and \code{ksline} are more adequate for
  prediction with fixed parameters.
  
  The basis for the Bayesian algorithm is to discretize the prior
  distribution for the parameters \eqn{\phi}{phi} and \eqn{\tau^2_{rel}
    =\frac{\tau^2}{\sigma^2}}{tau_rel = tau/sigma}.
  The Tech. Report referenced below provides more information
  on the technical details.
  
  The function call includes auxiliary control functions which allows
  the user to specify/change the model components (using \code{model.control}), prior
  distributions (using \code{prior.control}) and 
  output options (using \code{output.control}).
  There are default options. Only obligatory and arguments to be changed needs
  to be specified. The arguments of the controls functions are as follows:
  
  \emph{Control functions arguments:}
  
  \describe{
    
    \describe{\bold{Arguments for \code{model = model.control(\dots)} :}
      
      \item{trend.d}{information about the trend (covariates) values at the data
	locations. Possible values are:
	\cr
	\code{"cte"} - model with constant mean, i.e. no trend
	\cr
	\code{"1st"} - trend is defined as a first degree polynomial on the coordinates
	\cr
	\code{"2nd"} - trend is defined as a second degree polynomial on the
	coordinates
	\cr a formula of the type \code{~X}, where \code{X} is a matrix with covariates (external trend)
	at data locations.
	\cr
	Defaults to \code{"cte"}.}
      
      \item{trend.l}{Specifies the trend (covariate) at prediction
	locations. Must be the same type as defined in \code{trend.d}.
	Only used if prediction locations are provided in the argument
	\code{locations}.}
      
      \item{cov.model}{model for the correlation function. See options in the
	function call and/or documentation for the function \code{\link{cov.spatial}}. }
      
      \item{kappa}{additional parameter needed for some of the correlation
	functions: (\code{"matern", "powered.exponential", "gneiting"} and
	\code{"gneiting.matern"}). For more details see documentation for the
	function \code{\link{cov.spatial}}. This parameter is always regarded
	as fixed during the Bayesian analysis.}
      
      \item{aniso.pars}{fixed parameters for geometric anisotropy
	correction. If \code{aniso.pars = F} no correction is done otherwise
	a vector with 2 values, anisotropy angle and ratio of ranges, must be provided.}
      
      \item{lambda}{Box-Cox transformation parameter. If \eqn{\lambda = 1}{lambda = 1} no
	transformation is used, otherwise the Box-Cox data transformation is
	performed before the analysis. The transformation parameter \eqn{\lambda}{lambda}
	is regarded as a fixed parameter during the Bayesian analysis.
	The results are in the same scale as the original data.
	If \eqn{\lambda = 0}{lambda = 0} the log-transformation is performed.
	If \eqn{\lambda < 0}{lambda < 0} the mean predictor doesn't make sense
	(the resulting distribution has no expectation). }
      
    }
    
    \describe{\bold{Arguments for \code{prior = prior.control(\dots)} :}
      
      \item{beta.prior}{prior distribution for the mean (vector)
	parameter \eqn{\beta}{beta}. The options are "flat" (default), "normal" or "deg"
	(degenerated - known mean).}
      
      \item{beta}{hyperparameter for the distribution of the mean (vector) parameter
	\eqn{\beta}{beta}. Only used if \code{beta.prior = "normal"} or
	\code{beta.prior = "deg"}. For the later \code{beta} defines the value of
	the known mean.}
      
      \item{beta.var}{(co)variance hyperparameters for the prior of the mean
	(vector) parameter \eqn{\beta}{beta}. Only used if \code{beta.prior =
	  "normal"}.}
      
      \item{sill.prior}{\code{TRUE} (default) or \code{FALSE}, specifying
	whether or not the \emph{sill} parameter \eqn{\sigma^2}{sigma^2} is regarded as random during
	analysis. If \code{TRUE}, the prior assigned is
	\eqn{\frac{1}{\sigma^2}}{1/sigma^2}.}
      
      \item{sill}{fixed value of the sill parameter \eqn{\sigma^2}{sigma^2}. Only used if
	\code{sill.prior = FALSE}.}
      
      \item{range.prior}{prior distribution for the range parameter
	\eqn{\phi}{phi}. Options are: \code{\"uniform\"}, (\eqn{\propto
	  1}),
	\code{\"exponential\"} ,(\eqn{\exp(-\nu * \phi)}{exp(- nu * phi)})
        \code{\"fixed\"}, \code{\"squared.reciprocal\"},
	\code{\"reciprocal\"} (\eqn{\frac{1}{\phi}}{1/phi}),
	\code{\"squared.reciprocal\"} (\eqn{\frac{1}{\phi^2}}{1/phi^2}),
	\code{\"fixed\"} (known/estimated value of  \eqn{\phi}{phi}).
	If the latter is defined the parameter \eqn{\phi}{phi} is
	considered as known when performing prediction.}
      
      \item{exponential.prior.par}{parameter \eqn{\nu}{nu} for the exponential
	prior for the parameter \eqn{\phi}{phi}. Only used if \code{prior.phi = "exponential"}.}
      
      \item{range}{fixed value of the range parameter \eqn{\phi}{phi}. Only needed if
	\code{range.prior = "fixed"}.}
      
      \item{range.discrete}{support points for the discretisation of the prior
	for the range parameter \eqn{\phi}{phi}.}
      
      \item{nugget.prior}{specifies a prior distribution for the nugget
	parameter \eqn{\tau^2}{tau^2}. If \code{prior.nugget = "fixed"} the nugget is
	considered known (fixed) with value given by the argument
	\code{nugget}.
	If \code{prior.nugget = "uniform"} a discrete uniform prior is used
	with support points given by the argument \code{nugget}.}
      
      \item{nugget}{fixed value for the nugget parameter. Only used if
	\code{prior.nugget = "uniform"}.} 
      
      \item{nugget.discrete}{support points for the discretisation of the prior
	for the relative nugget parameter
	\eqn{\frac{\tau^2}{\sigma^2}}{tau^2/sigma^2}.}
      
    }

    
    \describe{\bold{Arguments for  \code{output = output.control(\dots)} :}
      
      \item{n.posterior}{number of samples taken from the posterior
	distribution.}
      
      \item{n.predictive}{number of samples taken from the
	predictive distribution.}
      
      \item{moments}{if \code{TRUE} moments of the predictive distribution
	are computed without sampling. This works only if \code{lambda = 1}
	or \code{lambda = 0}.}
      
      \item{simulations.predictive}{}
      
      \item{keep.simulations}{a flag \code{TRUE} or \code{FALSE} indicating
	whether or not the samples of the predictive distributions must be
	kept.
	Only used if prediction locations are provided on the argument \code{locations}.}
      
      \item{mean.estimator}{a flag \code{TRUE} or \code{FALSE} indicating
	whether or not the mean and variances of the predictive distributions must be
	computed and kept. If \code{TRUE} objects \code{predict.mean} and
	\code{krige.var} are included in the output.
	Only used prediction locations are provided on the argument \code{locations}.}
      
      \item{quantile.estimator}{indicates
	whether or not quantiles of the predictive distributions must be
	computed and kept. If a vector with numbers in the interval
	\eqn{\[0,1\]}{[0,1]} is provided the corresponding quantile(s) estimators
	are included in the output in the object \code{quantiles}. For
	example, if \code{estimator = c(0.25,0.50,0.75)} the function
	returns the 1st quartile, median and 3rd quartile for each location.
	If \code{TRUE}, the default is the vector c(0.025, 0.5, 0.975)
	and an uncertainty measure which is an analogy to the kriging
	standard error can be computed by \eqn{\(q0.975 - q0.025\)/4}.
	Only used prediction locations are provided on the argument \code{locations}.}
      
      \item{probability.estimator}{the default is \code{FALSE}. If some
	cutoff values are provided instead, an object called
	\code{probability} is included in the output providing, for each
	location, wthe probability of the variable be less or equal than the
	cutoff value given by the argument.}
      
      \item{signal}{if \code{TRUE} the signal is predict, otherwise the
	variable is predict. If no transformation is performed the
	expectations are the same in both cases and the difference is only in
	the kriging variance, if nugget is different form zero.}
      
      \item{messages.screen}{a flag \code{TRUE} or \code{FALSE} indicating
	whether or not messages are printend on the screen (or output file)
	while the function is running.}
      
    }   
  }
  
}

\value{A list with components:
  
  \item{\bold{posterior}}{A list results for the posterior distribution of the
    model parameters with the following components:}
  
  \cr
  
  \describe{   
    \item{* beta.summary}{summary statistics of the posterior distribution
      of the mean parameter \eqn{\beta}{beta}.}
    \item{* sigmasq.summary}{summary statistics of the posterior distribution
      of the variance parameter (sill) \eqn{\sigma^2}{sigma^2}.}
    \item{* phi.summary}{summary statistics of the posterior distribution
      of the correlation parameter (range) \eqn{\phi}{phi}.}
    \item{* tausq.summary}{summary statistics of the posterior distribution
      of the extra variance parameter (nugget) \eqn{\tau^2}{tau^2}.}
    \item{* beta.samples}{samples from the posterior distribution of the
      mean parameter \eqn{\beta}{beta}.}
    \item{* sigmasq.samples}{samples from the posterior distribution
      of the variance parameter (sill) \eqn{\sigma^2}{sigma^2}.}
    \item{* phi.samples}{samples from the posterior distribution
      of the correlation parameter (range) \eqn{\phi}{phi}.}
    \item{* tausq.samples}{samples from the posterior distribution
      of the extra variance parameter (nugget) \eqn{\tau^2}{tau^2}.}
    \item{* phi.marginal}{samples from the marginal posterior distribution
      of the correlation parameter (range) \eqn{\phi}{phi} (averaged ove the
      distribution of \eqn{\(\beta, \sigma^2\)}{(beta, sigma^2)}).}
    \item{* nugget.marginal}{samples from the marginal posterior distribution of the extra variance parameter (nugget) \eqn{\tau^2}{tau^2} (averaged ove the
      distribution of \eqn{\(\beta, \sigma^2\)}{(beta, sigma^2)}).}
    
  }
  
  \cr
  
  \item{\bold{predictive}}{A list results for the predictive distribution of the
    prediction locations (if provided), with the following
    components:}
  
  \cr  
  
  \describe{    
    \item{* moments}{a matrix where the colunms are moments of the
      predictive distribution at each prediction location}
    
    \item{* simulations}{a matrix where each column is a simulations drawn
      from the predictive distribution. Returned
      only if \code{keep.simulations = TRUE}.}
    \item{* mean.simulations}{a vector with the mean at the prediction
      locations computed using the simulations. Returned
      only if \code{mean.estimator = TRUE}.}
    \item{* variance.simulations}{a vector with the variance at the
      prediction locations computed using the simulations. Returned
      only if \code{mean.estimator = TRUE}.}
    \item{quantile}{A matrix or vector with quantile estimaors. Returned
      only if the argument \code{quantile.estimator} is used.}
    \item{* probability}{A matrix or vector with probability estimators. Returned
      only if the argument \code{probability.estimator} is used.}
    \item{* type.prediction}{information on the type of prediction performed}
    
  }
  
  \cr
  
  \item{\bold{message.prediction}}{information about the type of
    inference, concerning parameter uncertainty,
    which have been performed.}
  
  \item{\bold{.Random.seed}}{system random seed before run the function. Allows reproduction of results. If
    the system \code{.Random.seed} is set to this value and the function is run
    again, it will produce exactly the same results.}
  
  
  \item{\bold{call}}{the function call}
  
}

\references{
  The technical details for \code{krige.bayes} implementation can be
  found at:
  \cr
  
  Ribeiro, P.J. Jr. and Diggle, P.J. (1999) \emph{Bayesian inference in
    Gaussian model-based geostatistics}. Tech. Report ST-99-08, Depto
  Maths and Stats, Lancaster University.
  Available at: 
  \url{http://www.maths.lancs.ac.uk/~ribeiro/publications.html}
  
  Further information about \code{geoR/geoS} can be found at:
  \cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
  
}

\author{
  Paulo J. Ribeiro Jr. <\email{paulojus@est.ufpr.br}> \cr
  Peter J. Diggle <\email{p.diggle@lancaster.ac.uk}>.
}

\seealso{\code{\link{lines.krige.bayes}}, \code{\link{krige.conv}},
  \code{\link{ksline}}.
}


\examples{
# creating a simulated data-set
ex.data <- grf(70, cov.pars=c(10, .25), nugget=4)
#
# defining the prediction grid:
ex.grid <- as.matrix(expand.grid(seq(0,1,l=6), seq(0,1,l=6)))
#
# computing Bayesian posteriors and predictive distributions  
ex.bayes <- krige.bayes(ex.data, loc=ex.grid, prior =
                 prior.control(range.discrete=seq(0, 2, l=21)))

}

\keyword{spatial}

